@@ -4,13 +4,17 @@ use warnings;
 use 5.010; # state
 
 # ABSTRACT: Fully UTF-8 aware File::Find
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
-#pod =head1 SYNOPSIS
+#pod =begin :prelude
 #pod
 #pod =for test_synopsis
 #pod my @directories_to_search;
 #pod
+#pod =end :prelude
+#pod
+#pod =head1 SYNOPSIS
+#pod
 #pod     # Use the utf-8 versions of find and finddepth
 #pod     use File::Find::utf8;
 #pod     find(\&wanted, @directories_to_search);
@@ -117,7 +121,7 @@ our $SPECIALVARS = 0;
 #pod I<always> enforced.
 #pod =cut
 
-our $UTF8_CHECK = Encode::FB_CROAK; # Die on encoding errors
+our $UTF8_CHECK = Encode::FB_CROAK | Encode::LEAVE_SRC; # Die on encoding errors
 
 # UTF-8 Encoding object
 my $_UTF8 = Encode::find_encoding('UTF-8');
@@ -169,12 +173,11 @@ sub _utf8_find {
     # Holds the (possibly encoded) arguments
     my @args = @_;
 
-    # Enforce LEAVE_SRC
-    $UTF8_CHECK |= Encode::LEAVE_SRC if $UTF8_CHECK;
-
     # Get the hint from the caller (one level deeper if called from finddepth)
     my $hints = ((caller 1)[3]//'') ne 'File::Find::utf8::_utf8_finddepth' ? (caller 0)[10] : (caller 1)[10];
     if ($hints->{$current_package}) {
+        $UTF8_CHECK |= Encode::LEAVE_SRC if $UTF8_CHECK; # Enforce LEAVE_SRC
+
         # Save original processors
         my %org_proc;
         for my $proc ("wanted", "preprocess", "postprocess") { $org_proc{$proc} = $find_options_hash{$proc}; }
@@ -247,10 +250,28 @@ File::Find::utf8 - Fully UTF-8 aware File::Find
 
 =head1 VERSION
 
-version 0.010
+version 0.011
+
+=for test_synopsis my @directories_to_search;
 
 =head1 SYNOPSIS
 
+    # Use the utf-8 versions of find and finddepth
+    use File::Find::utf8;
+    find(\&wanted, @directories_to_search);
+
+    # Revert back to non-utf-8 versions
+    no File::Find::utf8;
+    finddepth(\&wanted, @directories_to_search);
+
+    # Export only the find function
+    use File::Find::utf8 qw(find);
+    find(\&wanted, @directories_to_search);
+
+    # Export no functions
+    use File::Find::utf8 qw(:none); # NOT "use File::Find::utf8 qw();"!
+    File::Find::find(\&wanted, @directories_to_search);
+
 =head1 DESCRIPTION
 
 While the original L<File::Find> functions are capable of handling
@@ -305,24 +326,6 @@ the encoding errors as warnings, and C<Encode::FB_DEFAULT> will completely
 ignore them. Please see L<Encode> for details. Note: C<Encode::LEAVE_SRC> is
 I<always> enforced.
 
-=for test_synopsis my @directories_to_search;
-
-    # Use the utf-8 versions of find and finddepth
-    use File::Find::utf8;
-    find(\&wanted, @directories_to_search);
-
-    # Revert back to non-utf-8 versions
-    no File::Find::utf8;
-    finddepth(\&wanted, @directories_to_search);
-
-    # Export only the find function
-    use File::Find::utf8 qw(find);
-    find(\&wanted, @directories_to_search);
-
-    # Export no functions
-    use File::Find::utf8 qw(:none); # NOT "use File::Find::utf8 qw();"!
-    File::Find::find(\&wanted, @directories_to_search);
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker
@@ -358,7 +361,7 @@ L<utf8::all> -- Turn on utf-8, all of it. This was also the module I first added
 
 =head1 AUTHOR
 
-Hayo Baan <hayobaan@cpan.org>
+Hayo Baan <info@hayobaan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
